@@ -1,17 +1,27 @@
-import ssl
+import re
 import time
+import warnings
 from typing import Any, Dict, Pattern, Tuple
 
 import requests.adapters
 import urllib3
 from requests import PreparedRequest, Request, Session
+from requests.adapters import HTTPAdapter
 
-from streamlink.exceptions import PluginError
+from streamlink.exceptions import PluginError, StreamlinkDeprecationWarning
 from streamlink.packages.requests_file import FileAdapter
 from streamlink.plugin.api import useragents
 from streamlink.utils.parse import parse_json, parse_xml
 
 
+try:
+    from urllib3.util import create_urllib3_context  # type: ignore[attr-defined]
+except ImportError:  # pragma: no cover
+    # urllib3 <2.0.0 compat import
+    from urllib3.util.ssl_ import create_urllib3_context
+
+
+# urllib3>=2.0.0: enforce_content_length now defaults to True (keep the override for backwards compatibility)
 class _HTTPResponse(urllib3.response.HTTPResponse):
     def __init__(self, *args, **kwargs):
         # Always enforce content length validation!
@@ -50,7 +60,9 @@ requests.adapters.HTTPResponse = _HTTPResponse  # type: ignore[misc]
 # > normalizers should use uppercase hexadecimal digits for all percent-
 # > encodings.
 class Urllib3UtilUrlPercentReOverride:
-    _re_percent_encoding: Pattern = urllib3.util.url.PERCENT_RE  # type: ignore[attr-defined]
+    # urllib3>=2.0.0: _PERCENT_RE, urllib3<2.0.0: PERCENT_RE
+    _re_percent_encoding: Pattern \
+        = getattr(urllib3.util.url, "_PERCENT_RE", getattr(urllib3.util.url, "PERCENT_RE", re.compile(r"%[a-fA-F0-9]{2}")))
 
     # urllib3>=1.25.8
     # https://github.com/urllib3/urllib3/blame/1.25.8/src/urllib3/util/url.py#L219-L227
@@ -59,7 +71,8 @@ class Urllib3UtilUrlPercentReOverride:
         return string, len(cls._re_percent_encoding.findall(string))
 
 
-urllib3.util.url.PERCENT_RE = Urllib3UtilUrlPercentReOverride  # type: ignore[attr-defined]
+# urllib3>=2.0.0: _PERCENT_RE, urllib3<2.0.0: PERCENT_RE
+urllib3.util.url._PERCENT_RE = urllib3.util.url.PERCENT_RE = Urllib3UtilUrlPercentReOverride  # type: ignore[attr-defined]
 
 
 # requests.Request.__init__ keywords, except for "hooks"
@@ -78,23 +91,27 @@ class HTTPSession(Session):
         self.mount("file://", FileAdapter())
 
     @classmethod
-    def determine_json_encoding(cls, sample):
+    def determine_json_encoding(cls, sample: bytes):
         """
         Determine which Unicode encoding the JSON text sample is encoded with
 
-        RFC4627 (http://www.ietf.org/rfc/rfc4627.txt) suggests that the encoding of JSON text can be determined
+        RFC4627 suggests that the encoding of JSON text can be determined
         by checking the pattern of NULL bytes in first 4 octets of the text.
+        https://datatracker.ietf.org/doc/html/rfc4627#section-3
+
         :param sample: a sample of at least 4 bytes of the JSON text
         :return: the most likely encoding of the JSON text
         """
-        nulls_at = [i for i, j in enumerate(bytearray(sample[:4])) if j == 0]
-        if nulls_at == [0, 1, 2]:
+        warnings.warn("Deprecated HTTPSession.determine_json_encoding() call", StreamlinkDeprecationWarning, stacklevel=1)
+        data = int.from_bytes(sample[:4], "big")
+
+        if data & 0xffffff00 == 0:
             return "UTF-32BE"
-        elif nulls_at == [0, 2]:
+        elif data & 0xff00ff00 == 0:
             return "UTF-16BE"
-        elif nulls_at == [1, 2, 3]:
+        elif data & 0x00ffffff == 0:
             return "UTF-32LE"
-        elif nulls_at == [1, 3]:
+        elif data & 0x00ff00ff == 0:
             return "UTF-16LE"
         else:
             return "UTF-8"
@@ -102,10 +119,12 @@ class HTTPSession(Session):
     @classmethod
     def json(cls, res, *args, **kwargs):
         """Parses JSON from a response."""
-        # if an encoding is already set then use the provided encoding
         if res.encoding is None:
-            res.encoding = cls.determine_json_encoding(res.content[:4])
-        return parse_json(res.text, *args, **kwargs)
+            # encoding is unknown: let ``json.loads`` figure it out from the bytes data via ``json.detect_encoding``
+            return parse_json(res.content, *args, **kwargs)
+        else:
+            # encoding is explicitly set: get the decoded string value and let ``json.loads`` parse it
+            return parse_json(res.text, *args, **kwargs)
 
     @classmethod
     def xml(cls, res, *args, **kwargs):
@@ -152,11 +171,11 @@ class HTTPSession(Session):
                 res = super().request(
                     method,
                     url,
+                    *args,
                     headers=headers,
                     params=params,
                     timeout=timeout,
                     proxies=proxies,
-                    *args,
                     **kwargs,
                 )
                 if raise_for_status and res.status_code not in acceptable_status:
@@ -181,12 +200,24 @@ class HTTPSession(Session):
         return res
 
 
-class TLSSecLevel1Adapter(requests.adapters.HTTPAdapter):
+class TLSNoDHAdapter(HTTPAdapter):
     def init_poolmanager(self, *args, **kwargs):
-        ctx = ssl.create_default_context()
+        ctx = create_urllib3_context()
+        ctx.load_default_certs()
+        ciphers = ":".join(cipher.get("name") for cipher in ctx.get_ciphers())
+        ciphers += ":!DH"
+        ctx.set_ciphers(ciphers)
+        kwargs["ssl_context"] = ctx
+        return super().init_poolmanager(*args, **kwargs)
+
+
+class TLSSecLevel1Adapter(HTTPAdapter):
+    def init_poolmanager(self, *args, **kwargs):
+        ctx = create_urllib3_context()
+        ctx.load_default_certs()
         ctx.set_ciphers("DEFAULT:@SECLEVEL=1")
         kwargs["ssl_context"] = ctx
         return super().init_poolmanager(*args, **kwargs)
 
 
-__all__ = ["HTTPSession", "TLSSecLevel1Adapter"]
+__all__ = ["HTTPSession", "TLSNoDHAdapter", "TLSSecLevel1Adapter"]
