@@ -1,10 +1,9 @@
 import ast
-import inspect
 import logging
 import operator
 import re
 import time
-import warnings
+from contextlib import suppress
 from functools import partial
 from http.cookiejar import Cookie
 from typing import (
@@ -123,9 +122,9 @@ def iterate_streams(streams):
     for name, stream in streams:
         if isinstance(stream, list):
             for sub_stream in stream:
-                yield (name, sub_stream)
+                yield name, sub_stream
         else:
-            yield (name, stream)
+            yield name, stream
 
 
 def stream_type_priority(stream_types, stream):
@@ -171,11 +170,8 @@ def parse_params(params: Optional[str] = None) -> Dict[str, Any]:
     matches = re.findall(PARAMS_REGEX, params)
 
     for key, value in matches:
-        try:
+        with suppress(Exception):
             value = ast.literal_eval(value)
-        except Exception:
-            pass
-
         rval[key] = value
 
     return rval
@@ -220,16 +216,6 @@ class Matches(_MCollection[Optional[Match]]):
         return next(((matcher.pattern, match) for matcher, match in matches if match is not None), (None, None))
 
 
-# Add front- and back-wrappers to the deprecated plugin's method resolution order (see Plugin.__new__)
-class PluginWrapperMeta(type):
-    def mro(cls):
-        # cls.__base__ is the PluginWrapperFront which is based on the deprecated plugin class
-        mro = list(cls.__base__.__mro__)
-        # cls is the PluginWrapperBack and needs to be inserted after the deprecated plugin class
-        mro.insert(2, cls)
-        return mro
-
-
 class Plugin:
     """
     Plugin base class for retrieving streams and metadata from the URL specified.
@@ -262,6 +248,9 @@ class Plugin:
     match: Optional[Match] = None
     """A reference to the :class:`re.Match` result of the first matching matcher"""
 
+    options: Options
+    """Plugin options, initialized with the user-set values of the plugin's arguments"""
+
     # plugin metadata attributes
     id: Optional[str] = None
     """Metadata 'id' attribute: unique stream ID, etc."""
@@ -272,61 +261,19 @@ class Plugin:
     category: Optional[str] = None
     """Metadata 'category' attribute: name of a game being played, a music genre, etc."""
 
-    options = Options()
     _url: str = ""
 
-    # deprecated
-    can_handle_url: Callable[[str], bool]
-    # deprecated
-    priority: Callable[[str], int]
-
-    # Handle deprecated plugin constructors which only take the url argument
-    def __new__(cls, *args, **kwargs):
-        # Ignore plugins without custom constructors or wrappers
-        if cls.__init__ is Plugin.__init__ or hasattr(cls, "_IS_DEPRECATED_PLUGIN_WRAPPER"):
-            return super().__new__(cls)
-
-        # Ignore custom constructors which have a formal "session" parameter or a variable positional parameter
-        sig = inspect.signature(cls.__init__).parameters
-        if "session" in sig or any(param.kind == inspect.Parameter.VAR_POSITIONAL for param in sig.values()):
-            return super().__new__(cls)
-
-        # Wrapper class which overrides the very first constructor in the MRO
-        # noinspection PyAbstractClass
-        class PluginWrapperFront(cls):
-            _IS_DEPRECATED_PLUGIN_WRAPPER = True
-
-            # The __module__ value needs to be copied
-            __module__ = cls.__module__
-
-            def __init__(self, session, url):
-                # Take any arguments, but only pass the URL to the custom constructor of the deprecated plugin
-                # noinspection PyArgumentList
-                super().__init__(url)
-                warnings.warn(
-                    f"Initialized {self.module} plugin with deprecated constructor",
-                    FutureWarning,
-                )
-
-        # Wrapper class which comes after the deprecated plugin in the MRO
-        # noinspection PyAbstractClass
-        class PluginWrapperBack(PluginWrapperFront, metaclass=PluginWrapperMeta):
-            def __init__(self, *_, **__):
-                # Take any arguments from the super() call of the constructor of the deprecated plugin,
-                # but pass the right args and keywords to the Plugin constructor
-                super().__init__(*args, **kwargs)
-
-        return cls.__new__(PluginWrapperBack, *args, **kwargs)
-
-    def __init__(self, session: "Streamlink", url: str):
+    def __init__(self, session: "Streamlink", url: str, options: Optional[Options] = None):
         """
         :param session: The Streamlink session instance
         :param url: The input URL used for finding and resolving streams
+        :param options: An optional :class:`Options` instance
         """
 
         modulename = self.__class__.__module__
         self.module = modulename.split(".")[-1]
         self.logger = logging.getLogger(modulename)
+        self.options = Options() if options is None else options
         self.cache = Cache(
             filename="plugin-cache.json",
             key_prefix=self.module,
@@ -354,13 +301,11 @@ class Plugin:
         if self.matchers:
             self.matcher, self.match = self.matches.update(self.matchers, value)
 
-    @classmethod
-    def set_option(cls, key, value):
-        cls.options.set(key, value)
+    def set_option(self, key, value):
+        self.options.set(key, value)
 
-    @classmethod
-    def get_option(cls, key):
-        return cls.options.get(key)
+    def get_option(self, key):
+        return self.options.get(key)
 
     @classmethod
     def get_argument(cls, key):
@@ -374,7 +319,7 @@ class Plugin:
     def default_stream_types(cls, streams):
         stream_types = ["hls", "http"]
 
-        for name, stream in iterate_streams(streams):
+        for _name, stream in iterate_streams(streams):
             stream_type = type(stream).shortname()
 
             if stream_type not in stream_types:
@@ -388,7 +333,7 @@ class Plugin:
 
         Returns a :class:`dict` containing the streams, where the key is
         the name of the stream (most commonly the quality name), with the value
-        being a :class:`Stream` instance.
+        being a :class:`Stream <streamlink.stream.Stream>` instance.
 
         The result can contain the synonyms **best** and **worst** which
         point to the streams which are likely to be of highest and
@@ -414,7 +359,7 @@ class Plugin:
 
         :param stream_types: A list of stream types to return
         :param sorting_excludes: Specify which streams to exclude from the best/worst synonyms
-        :returns: A :class:`dict` of stream names and :class:`streamlink.stream.Stream` instances
+        :returns: A :class:`dict` of stream names and :class:`Stream <streamlink.stream.Stream>` instances
         """
 
         try:
@@ -428,7 +373,7 @@ class Plugin:
         except NoStreamsError:
             return {}
         except (OSError, ValueError) as err:
-            raise PluginError(err)
+            raise PluginError(err) from err
 
         if not ostreams:
             return {}
@@ -482,7 +427,7 @@ class Plugin:
 
         # Create the best/worst synonyms
         def stream_weight_only(s):
-            return (self.stream_weight(s)[0] or (len(streams) == 1 and 1))
+            return self.stream_weight(s)[0] or (len(streams) == 1 and 1)
 
         stream_names = filter(stream_weight_only, streams.keys())
         sorted_streams = sorted(stream_names, key=stream_weight_only)
@@ -517,8 +462,9 @@ class Plugin:
         """
         Implement the stream and metadata retrieval here.
 
-        Needs to return either a dict of :class:`streamlink.stream.Stream` instances mapped by stream name, or needs to act
-        as a generator which yields tuples of stream names and :class:`streamlink.stream.Stream` instances.
+        Needs to return either a dict of :class:`Stream <streamlink.stream.Stream>` instances mapped by stream name,
+        or needs to act as a generator which yields tuples of stream names and :class:`Stream <streamlink.stream.Stream>`
+        instances.
         """
 
         raise NotImplementedError
@@ -607,7 +553,7 @@ class Plugin:
     def clear_cookies(self, cookie_filter: Optional[Callable] = None) -> List[str]:
         """
         Removes all saved cookies for this plugin. To filter the cookies that are deleted
-        specify the ``cookie_filter`` argument (see :func:`save_cookies`).
+        specify the ``cookie_filter`` argument (see :meth:`save_cookies`).
 
         :param cookie_filter: a function to filter the cookies
         :type cookie_filter: function
@@ -633,7 +579,7 @@ class Plugin:
             try:
                 return user_input_requester.ask(prompt)
             except OSError as err:
-                raise FatalPluginError(f"User input error: {err}")
+                raise FatalPluginError(f"User input error: {err}") from err
         raise FatalPluginError("This plugin requires user input, however it is not supported on this platform")
 
     def input_ask_password(self, prompt: str) -> str:
@@ -642,7 +588,7 @@ class Plugin:
             try:
                 return user_input_requester.ask_password(prompt)
             except OSError as err:
-                raise FatalPluginError(f"User input error: {err}")
+                raise FatalPluginError(f"User input error: {err}") from err
         raise FatalPluginError("This plugin requires user input, however it is not supported on this platform")
 
 
@@ -657,7 +603,7 @@ def pluginmatcher(
     A matcher consists of a compiled regular expression pattern for the plugin's input URL,
     a priority value and an optional name.
     The priority value determines which plugin gets chosen by
-    :meth:`Streamlink.resolve_url <streamlink.Streamlink.resolve_url>` if multiple plugins match the input URL.
+    :meth:`Streamlink.resolve_url() <streamlink.session.Streamlink.resolve_url>` if multiple plugins match the input URL.
     The matcher name can be used for accessing it and its matching result when multiple matchers are defined.
 
     Plugins must at least have one matcher. If multiple matchers are defined, then the first matching one
@@ -708,11 +654,10 @@ def pluginargument(
     sensitive: bool = False,
     argument_name: Optional[str] = None,
     dest: Optional[str] = None,
-    is_global: bool = False,
     **options,
 ) -> Callable[[Type[Plugin]], Type[Plugin]]:
     """
-    Decorator for plugin arguments. Takes the same arguments as :class:`streamlink.options.Argument`.
+    Decorator for plugin arguments. Takes the same arguments as :class:`Argument <streamlink.options.Argument>`.
 
     .. code-block:: python
 
@@ -746,7 +691,6 @@ def pluginargument(
         sensitive=sensitive,
         argument_name=argument_name,
         dest=dest,
-        is_global=is_global,
         **options,
     )
 
